| Type: | Package |
| Title: | Unidimensional and Multidimensional Reliability Coefficients |
| Version: | 1.0.1 |
| Description: | Calculates and compares various reliability coefficients for unidimensional and multidimensional scales. Supported unidimensional estimators include coefficient alpha, congeneric reliability, the Gilmer-Feldt coefficient, Feldt's classical congeneric reliability, Hancock's H, Heise-Bohrnstedt's omega, Kaiser-Caffrey's alpha, and Ten Berge and Zegers' mu series. Multidimensional estimators include stratified alpha, maximal reliability, correlated factors reliability, second-order factor reliability, and bifactor reliability. See Cho (2021) <doi:10.1007/s11336-021-09801-1>, Cho (2024) <doi:10.1037/met0000475>, Cho (2025) <doi:10.1037/met0000525>. |
| License: | GPL (≥ 3) |
| Encoding: | UTF-8 |
| LazyData: | true |
| RoxygenNote: | 7.3.3 |
| Imports: | lavaan, psych, matrixcalc, stats |
| Suggests: | knitr, rmarkdown, Rcsdp, testthat (≥ 3.0.0) |
| Depends: | R (≥ 3.5.0) |
| VignetteBuilder: | knitr |
| NeedsCompilation: | no |
| Packaged: | 2026-02-28 03:01:28 UTC; bene |
| Author: | Eunseong Cho [aut, cre] |
| Maintainer: | Eunseong Cho <bene@kw.ac.kr> |
| Repository: | CRAN |
| Date/Publication: | 2026-03-05 10:30:10 UTC |
Cho's (2016) artificial unidimensional data of four items
Description
A hypothetical data consisting of four items.
A hypothetical data consisting of four items.
Usage
data(Cho2016)
data(Cho2016)
Format
An object of class matrix (inherits from array) with 4 rows and 4 columns.
An object of class matrix (inherits from array) with 4 rows and 4 columns.
Author(s)
Eunseong Cho, bene@kw.ac.kr
Cho, E. (2016). Making reliability reliable: A systematic approach to reliability coefficients. Organizational Research Methods, 19(4), 651-682.
Cho, E. (2016). Making reliability reliable: A systematic approach to reliability coefficients. Organizational Research Methods, 19(4), 651-682.
Synthetic Multi-dimensional Covariance Matrix from Cho (2025)
Description
A 12x12 synthetic covariance matrix generated based on the simulation conditions described in Cho (2025). The data was generated as a random matrix with the following specifications: sample size (n) = 50, 4 group factors, and 3 items per group factor. The factor loading sizes within each factor are in a decreasing pattern. The general factor loading size relative to the group factor loading size is set to 'group', and there are no cross-loadings.
Usage
Cho_multi
Format
A 12x12 numeric matrix.
- X11, X12, X13
Items for Factor 1
- X21, X22, X23
Items for Factor 2
- X31, X32, X33
Items for Factor 3
- X41, X42, X43
Items for Factor 4
Cho, E. (2025). Reliability and omega hierarchical in multidimensional data: A comparison of various estimators. Psychological Methods, 30(1), 40–59.
Examples
data(Cho_multi)
multirel(Cho_multi, until = c(3, 6, 9))
Graham's (2006) first unidimensional data
Description
Graham's (2006) artificial dataset consisting of five items.This is the second dataset in his Table 2. The last item is about five times as important as the other items. This dataset provides a good indication of how sensitive each reliability coefficient is to the violation of the tau equivalence assumption. The CFA reliability coefficient presented by the author is .97.
Graham's (2006) artificial dataset consisting of five items.This is the second dataset in his Table 2. The last item is about five times as important as the other items. This dataset provides a good indication of how sensitive each reliability coefficient is to the violation of the tau equivalence assumption. The CFA reliability coefficient presented by the author is .97.
Usage
data(Graham1)
data(Graham1)
Format
An object of class matrix (inherits from array) with 5 rows and 5 columns.
An object of class matrix (inherits from array) with 5 rows and 5 columns.
Author(s)
Eunseong Cho, bene@kw.ac.kr
Graham, J. M. (2006). Congeneric and (essentially) tau-equivalent estimates of score reliability what they are and how to use them. Educational and Psychological Measurement, 66(6), 930-944. Education and Macmillan.
Graham, J. M. (2006). Congeneric and (essentially) tau-equivalent estimates of score reliability what they are and how to use them. Educational and Psychological Measurement, 66(6), 930-944. Education and Macmillan.
Obtain Coefficient Alpha
Description
Alpha, also referred to as Cronbach's alpha or tau-equivalent reliability, is the most commonly used reliability coefficient.
Usage
alpha(x, standardized = FALSE)
Arguments
x |
a data frame of raw data or a covariance matrix |
standardized |
If TRUE, the calculation is based on the correlation matrix. |
Details
History: Kuder and Richardson (1937) first developed this formula, but they did not name it alpha. At the time, it was referred to as Kuder-Richardson Formula 20. Cronbach (1951) argued that this name was strange and insisted on calling it coefficient alpha, which is now widely used.
Interpretations: Alpha can be derived with an ANOVA approach to reliability (Hoyt 1941). Alpha is lambda3, one of the six lower bounds of reliability (Guttman 1945). Alpha is the average of lambda4 values obtained over all possible split-halves (Cronbach 1951). Alpha equals reliability if the x meets the condition of being essentially tau-equivalent (Novick & Lewis, 1967). Alpha is mu0, the first in Ten Berge and Socan's (1978) series of reliability coefficients.
Accuracy: Alpha is found to be inferior in several studies examining the accuracy of the reliability coefficients (Cho 2024a, 2024b). Alpha can produce negative reliability estimates and is sensitive to the violation of the assumption of essential tau-equivalence (Cho 2021; Cho and Kim 2015).
Value
Coefficient alpha reliability estimate.
References
Cho, E. (2021). Neither Cronbach's alpha nor McDonald's omega: A comment on Sijtsma and Pfadt. Psychometrika, 86(4), 877-886.
Cho, E. (2024a). Beyond alpha and omega: The accuracy of single-test reliability estimators in unidimensional continuous data. Behavior Research Methods, 56(6), 6299-6317.
Cho, E. (2024b). The accuracy of reliability coefficients: A reanalysis of existing simulations. Psychological Methods, 29(2), 331-349.
Cho, E., & Kim, S. (2015). Cronbach's coefficient alpha: Well known but poorly understood. Organizational Research Methods, 18(2), 207-230.
Cronbach, L. J. (1951). Coefficient alpha and the internal structure of tests. Psychometrika, 16(3), 297-334
Guttman, L. (1945). A basis for analyzing test-retest reliability. Psychometrika, 10(4), 255-282.
Hoyt, C. (1941). Test reliability estimated by analysis of variance. Psychometrika, 6(3), 153-160.
Kuder, G. F., & Richardson, M. W. (1937). The theory of the estimation of test reliability. Psychometrika, 2(3), 151-160.
Novick, M. R., & Lewis, C. (1967). Coefficient alpha and the reliability of composite measurements. Psychometrika, 32(1), 1-13.
Ten Berge, J. M. F., & Zegers, F. E. (1978). A series of lower bounds to the reliability of a test. Psychometrika, 43(4), 575-579.
See Also
[mu0()] alpha equals mu0.
Examples
alpha(Graham1)
alpha(Graham1, standardized = TRUE)
Obtain bifactor reliability estimates
Description
Obtain bifactor reliability estimates. It is a multidimensional CFA reliability coefficient derived from the bifactor model. Items should be grouped by each sub-dimension.
Usage
bifactor(x, until, standardized = FALSE)
Arguments
x |
a data frame of raw data or a covariance matrix |
until |
a vector of indices indicating the last item of each sub-dimension |
standardized |
If TRUE, the calculation is based on the correlation matrix. |
Value
a list of class 'reliacoef' containing bifactor reliability estimates
Author(s)
Eunseong Cho, bene@kw.ac.kr
Examples
bifactor(Cho_multi, c(3, 6, 9))
Obtain correlated factors reliability estimates
Description
Obtain correlated factors reliability estimates. It is a multidimensional CFA reliability coefficient derived from the correlated factors model. Items should be grouped by each sub-dimension.
Usage
correlated_factors(x, until, standardized = FALSE)
Arguments
x |
a data frame of raw data or a covariance matrix |
until |
a vector of indices indicating the last item of each sub-dimension |
standardized |
If TRUE, the calculation is based on the correlation matrix. |
Value
a list of class 'reliacoef' containing correlated factors reliability estimates
Author(s)
Eunseong Cho, bene@kw.ac.kr
Examples
correlated_factors(Cho_multi, c(3, 6, 9))
Obtain Feldt's classical congeneric reliability coefficient
Description
Feldt's classical congeneric reliability (Feldt & Brennan 1989) is a unidimensional reliability coefficient based on a congeneric model. The congeneric model is a model that allows the length, discrimination, or importance of items to be different, and is the least restrictive model among the models derived from the classical test theory. The congeneric reliability proposed by Joreskog (1971) uses an optimization technique called maximum likelihood to estimate the "length" of an item. Classical congeneric reliablity uses a simpler logic, using the ratio of the sum of the covariance of the item to the sum of the total covariance as an estimate of the length of the item (Cho 2016).This coefficient is slightly less accurate than the Gilmer-Fedlt coefficient or congeneric reliability (Cho in press).
Usage
feldt(x, standardized = FALSE)
Arguments
x |
a dataframe or a matrix (unidimensional) |
standardized |
If TRUE, the calculation is based on the correlation matrix. |
Value
classical congeneric reliability coefficient
References
Cho, E. (2016). Making reliability reliable: A systematic approach to reliability coefficients. Organizational Research Methods, 19(4), 651–682.
Cho, E. (in press). Neither Cronbach's alpha nor McDonald's omega: A comment on Sijtsma and Pfadt. Psychometrika.
Feldt, L. S., & Brennan, R. L. (1989). Reliability. In R. L. Linn (Ed.), Educational measurement (3rd ed., pp. 105–146). American Council on Education and Macmillan.
Jöreskog, K. G. (1971). Statistical analysis of sets of congeneric tests. Psychometrika, 36(2), 109–133.
See Also
[gilmer()] for the Gilmer-Fedlt coefficient
[joreskog()] for congeneric (unidimensional CFA) reliability
Examples
feldt(Graham1)
Obtain the Covariance Matrix
Description
If the input data is a square and symmetric matrix, it is treated as an existing covariance/correlation matrix. Otherwise, a covariance matrix is calculated from the raw data.
Usage
get_cov(x, cor = FALSE)
Arguments
x |
A dataframe or a matrix. |
cor |
If TRUE, return the correlation matrix. If FALSE, return the covariance matrix. |
Value
The covariance or correlation matrix.
Obtain the Gilmer-Feldt reliability coefficient
Description
It is a unidimensional reliability coefficient based on a congeneric model. The congeneric model is a model that allows the length, discrimination, or importance of items to be different, and is the least restrictive model among the models derived from the classical test theory. The Gilmer-Feldt coefficient has the advantage of being less computational than congeneric reliability (Joreskog 1971) which uses confirmatory factor analysis. However, the Gilmer-Feldt coefficient derives a value very close to congeneric reliability (Cho in press). Feldt and Charter (2003) offers a user-friendly review of the Gilmer-Feldt coefficient.
Usage
gilmer(x, standardized = FALSE)
Arguments
x |
a data frame of raw data or a covariance matrix |
standardized |
If TRUE, the calculation is based on the correlation matrix. |
Value
The Gilmer-Feldt coefficient
References
Cho, E. (in press). Neither Cronbach's alpha nor McDonald's omega: A comment on Sijtsma and Pfadt. Psychometrika.
Feldt, L. S., & Charter, R. A. (2003). Estimation of internal consistency reliability when test parts vary in effective length. Measurement and Evaluation in Counseling and Development, 36(1), 23-27
Gilmer, J. S., & Feldt, L. S. (1983). Reliability estimation for a test with parts of unknown lengths. Psychometrika, 48(1), 99–111.
Jöreskog, K. G. (1971). Statistical analysis of sets of congeneric tests. Psychometrika, 36(2), 109–133.
Examples
gilmer(Graham1)
Obtain Hancock's H (CFA version of maximal reliability)
Description
It is the confirmatory factor analysis (CFA) version of maximal reliability. This coefficient takes the standardized factor loading as the reliability of each item, and finds the weight that maximizes the reliability. Hence, Hancock's H shows a different result than the reliability estimator using conventional unit weights.
Usage
hancock(x, standardized = FALSE)
Arguments
x |
a data frame of raw data or a covariance matrix |
standardized |
If TRUE, the calculation is based on the correlation matrix. |
Value
Hancock's H
References
Cho, E. (in press). Neither Cronbach's alpha nor McDonald's omega: A comment on Sijtsma and Pfadt. Psychometrika.
Hancock, G., & Mueller, R. O. (2001). Rethinking construct reliability within latent variable systems. In R. Cudeck, S. du Toit, & D. Sörbom (Eds.), Structural equation modeling: Present and future-A festschrift in honor of Karl Jöreskog (pp. 195-216). Scientific Software International.
Li, H., Rosenthal, R., & Rubin, D. B. (1996). Reliability of measurement in psychology: From Spearman-Brown to maximal reliability. Psychological Methods, 1(1), 98-107.
McNeish, D. (2017). Thanks coefficient alpha, we’ll take it from here. Psychological Methods, 23(3), 412-433.
Examples
hancock(Graham1)
Obtain Hancock and An's (2020) coefficient
Description
Hancock and An (2020) published a reliability estimator they called the "closed-form omega", which is designed to approximate a unidimensional confirmatory factor analysis reliability estimator (i.e., joreskog).
Usage
hancockan(x, standardized = FALSE)
Arguments
x |
a data frame of raw data or a covariance matrix |
standardized |
If TRUE, the calculation is based on the correlation matrix. |
Value
Hancock and An's reliability coefficient
Author(s)
Eunseong Cho, bene@kw.ac.kr
References
Hancock, G. R., & An, J. (2020). A Closed-Form Alternative for Estimating omega Reliability under Unidimensionality. Measurement: Interdisciplinary Research and Perspectives, 18(1), 1-14. https://doi.org/10.1080/15366367.2019.1656049
Examples
hancockan(Graham1)
Obtain Heise-Bohrnstedt's Omega
Description
Heise-Bohrnstedt's (1970) Omega is an factor analysis (FA) reliability. This formula is different from the FA reliability we use today and yields a larger value (Cho, in press). McDonald (1999) referred to all FA reliability as omega, and capitalized omega was used to distinguish it from McDonald's omega.
Usage
heise(x, standardized = FALSE)
Arguments
x |
a data frame of raw data or a covariance matrix |
standardized |
If TRUE, the calculation is based on the correlation matrix. |
Value
Heise-Bohrnstedt's Omega
References
Cho, E. (in press). Neither Cronbach's alpha nor McDonald's omega: A comment on Sijtsma and Pfadt. Psychometrika.
Heise, D. R., & Bohrnstedt, G. W. (1970). Validity, invalidity, and reliability. Sociological Methodology, 2, 104-129.
McDonald, R. P. (1999). Test theory: A unified treatment. Lawrence Erlbaum.
Examples
heise(Graham1)
Obtain Joreskog's congeneric reliability (Unidimensional CFA reliability)
Description
Congeneric reliability is a reliability coefficient derived from unidimensional confirmatory factor analysis (CFA).
Usage
joreskog(x, standardized = FALSE)
Arguments
x |
a data frame of raw data or a covariance matrix |
standardized |
If TRUE, the calculation is based on the correlation matrix. |
Details
Features: Congeneric reliability is a unidimensional reliability coefficient based on a unidimensional confirmatory factor analysis (CFA) model.
Name: Congeneric reliability is called by a variety of names, general users usually call it composite reliability, and reliability researchers often call it omega. One of the reasons for this confusion is that studies that first proposed this coefficient (Joreskog 1971) did not give this formula a name (Cho 2016). Joreskog (1971) proposed a matrix-form formula, and the commonly known non-matrix formula appears in Werts et al. (1974).
Frequency of use: Congeneric reliability is the second most commonly used reliability coefficient after coefficient alpha (Cho 2016)
Accuracy: Congeneric reliability is the most accurate reliability coefficient along with the Feldt-Gilmer coefficient (Cho in press)
Computation: This function uses maximum likelihood as estimation, unstandardized covariance matrix as input, and lavaan package as software.
Value
congeneric reliability coefficient
References
Cho, E. (2016). Making reliability reliable: A systematic approach to reliability coefficients. Organizational Research Methods, 19(4), 651-682.
Cho, E. (in press). Neither Cronbach's alpha nor McDonald's omega: A comment on Sijtsma and Pfadt. Psychometrika.
Joreskog, K. G. (1971). Statistical analysis of sets of congeneric tests. Psychometrika, 36(2), 109-133.
Werts, C. E., Linn, R. L., & Joreskog, K. G. (1974). Intraclass reliability estimates: Testing structural assumptions. Educational and Psychological Measurement, 34, 25-33.
See Also
[gilmer()] for the Gilmer-Feldt coefficient
[feldt()] for classical congeneric reliability coefficient
Examples
joreskog(Graham1)
Obtain Kaiser-Caffrey's alpha (principal component analysis reliability)
Description
Kaiser-Caffrey's (1965) alpha is the principal component analysis (PCA) reliability. They presented this formula in the context of factor analysis, but Bentler (1968) showed that it was in fact PCA reliability. Armor (1974), citing Bentler (1968), referred to this formula as theta, and some studies refer to it as Armor's theta. Kaiser and Caffrey (1965) labeled this formula alpha, and people may have mistaken it for coefficient alpha. See Vehkalahti (2000) and Cho(in press) for further explanation of this formula.
Usage
kaisercaffrey(x, standardized = FALSE)
Arguments
x |
a data frame of raw data or a covariance matrix |
standardized |
If TRUE, the calculation is based on the correlation matrix. |
Value
Kaiser-Caffrey's alpha
References
Armor, D. J. (1974). Theta reliability and factor scaling. In H. L. Costner (Ed.), Sociological methodology (pp. 17-50). Jossey-Bass.
Bentler, P. M. (1968). Alpha-maximized factor analysis (alphamax) : Its relation to alpha and canonical factor analysis. Psychometrika, 33(3), 335-345.
Cho, E. (in press). Neither Cronbach's alpha nor McDonald's omega: A comment on Sijtsma and Pfadt. Psychometrika.
Kaiser, H. F., & Caffrey, J. (1965). Alpha factor analysis. Psychometrika, 30(1), 1-14.
Vehkalahti, K. (2000). Reliability of measurement scales: Tarkkonen's general method supersedes Cronbach's alpha. University of Helsinki.
Examples
kaisercaffrey(Graham1)
Obtain Ten Berge and Zegers' (1978) mu1
Description
Obtain Ten Berge and Zegers' (1978) mu1. mu1 equals Guttman's (1945) lambda2.
Usage
lambda2(x, standardized = FALSE)
Arguments
x |
a data frame of raw data or a covariance matrix |
standardized |
If TRUE, the calculation is based on the correlation matrix. |
Value
Guttman's lambda2 (mu1) reliability estimate.
Author(s)
Eunseong Cho, bene@kw.ac.kr
References
Guttman, L. (1945). A basis for analyzing test-retest reliability. Psychometrika, 10(4), 255-282.
Ten Berge, J. M. F., & Zegers, F. E. (1978). A series of lower bounds to the reliability of a test. Psychometrika, 43(4), 575-579.
Obtain the Maximum Split-Half Reliability (Lambda4)
Description
Lambda4 is a lower bound of reliability based on a split-half of a test. This function searches through all possible split-halves to find the maximum value, which provides the best lower bound among all possible splits.
Usage
lambda4_max(x, standardized = FALSE)
Arguments
x |
a data frame of raw data or a covariance matrix |
standardized |
If TRUE, the calculation is based on the correlation matrix. |
Value
The maximum lambda4 reliability estimate.
References
Guttman, L. (1945). A basis for analyzing test-retest reliability. Psychometrika, 10(4), 255-282.
Obtain Guttman's Lambda5
Description
Lambda5 is one of the six lower bounds of reliability established by Guttman (1945). It is particularly useful when one item has large absolute covariances with other items compared to the covariances among those items.
Usage
lambda5(x, standardized = FALSE)
Arguments
x |
a data frame of raw data or a covariance matrix |
standardized |
If TRUE, the calculation is based on the correlation matrix. |
Value
Guttman's lambda5 reliability estimate.
References
Guttman, L. (1945). A basis for analyzing test-retest reliability. Psychometrika, 10(4), 255-282.
Obtain Guttman's Lambda6
Description
Lambda6 is a lower bound of reliability based on linear multiple correlation. It tends to be larger than other bounds when items have relatively low zero-order intercorrelations but high multiple correlations.
Usage
lambda6(x, standardized = FALSE)
Arguments
x |
a data frame of raw data or a covariance matrix |
standardized |
If TRUE, the calculation is based on the correlation matrix. |
Value
Guttman's lambda6 reliability estimate.
References
Guttman, L. (1945). A basis for analyzing test-retest reliability. Psychometrika, 10(4), 255-282.
Obtain maximal reliability estimates of two-dimensional data
Description
Obtain maximal reliability estimates of two-dimensional data. Items should be grouped by each sub-dimension.
Usage
maximal_reliability(x, until, standardized = FALSE)
Arguments
x |
a data frame of raw data or a covariance matrix |
until |
a vector of indices indicating the last item of each sub-dimension |
standardized |
If TRUE, the calculation is based on the correlation matrix. |
Value
a list of class 'reliacoef' containing the maximal reliability estimate
Author(s)
Eunseong Cho, bene@kw.ac.kr
References
Li, H., Rosenthal, R., & Rubin, D. B. (1996). Reliability of measurement in psychology: From Spearman-Brown to maximal reliability. Psychological Methods, 1(1), 98-107. https://doi.org/10.1037/1082-989X.1.1.98
Examples
maximal_reliability(Cho_multi, c(3, 6, 9))
Obtain Ten Berge and Zegers' (1978) mu1
Description
Obtain Ten Berge and Zegers' (1978) mu1. mu1 equals Guttman's (1945) lambda2.
Usage
mu1(x, standardized = FALSE)
Arguments
x |
a data frame of raw data or a covariance matrix |
standardized |
If TRUE, the calculation is based on the correlation matrix. |
Value
Guttman's lambda2 (mu1) reliability estimate.
Author(s)
Eunseong Cho, bene@kw.ac.kr
References
Guttman, L. (1945). A basis for analyzing test-retest reliability. Psychometrika, 10(4), 255-282.
Ten Berge, J. M. F., & Zegers, F. E. (1978). A series of lower bounds to the reliability of a test. Psychometrika, 43(4), 575-579.
Obtain Ten Berge and Zegers' (1978) mu2
Description
Obtain Ten Berge and Zegers' (1978) mu2.
Usage
mu2(x, standardized = FALSE)
Arguments
x |
a data frame of raw data or a covariance matrix |
standardized |
If TRUE, the calculation is based on the correlation matrix. |
Value
Ten Berge and Zegers' mu2 reliability estimate.
Author(s)
Eunseong Cho, bene@kw.ac.kr
References
Ten Berge, J. M. F., & Zegers, F. E. (1978). A series of lower bounds to the reliability of a test. Psychometrika, 43(4), 575-579.
Examples
mu2(Graham1)
Obtain Ten Berge and Socan's (2004) mu3
Description
Obtain Ten Berge and Socan's (2004) mu3.
Usage
mu3(x, standardized = FALSE)
Arguments
x |
a data frame of raw data or a covariance matrix |
standardized |
If TRUE, the calculation is based on the correlation matrix. |
Details
The original formula and the formula of psych's tenberge() are different. There is a high possibility that the original formula is incorrect and psych's version is correct. According to Equation (4) of the original article, mu should increase monotonically (e.g., mu4>=mu3), but if the original formula is followed, it may decrease in some cases. The formula of the original paper is 2h, but changing it to 2^h solves this problem. This function follow the latter interpretation.
Value
Ten Berge and Zegers' mu3 reliability estimate.
Author(s)
Eunseong Cho, bene@kw.ac.kr
References
Ten Berge, J. M. F., & Zegers, F. E. (1978). A series of lower bounds to the reliability of a test. Psychometrika, 43(4), 575-579.
Examples
mu3(Graham1)
Obtain Ten Berge and Socan's (2004) mu4
Description
Obtain Ten Berge and Socan's (2004) mu4.
Usage
mu4(x, standardized = FALSE)
Arguments
x |
a data frame of raw data or a covariance matrix |
standardized |
If TRUE, the calculation is based on the correlation matrix. |
Details
The original formula and the formula of psych's tenberge() are different. There is a high possibility that the original formula is incorrect and psych's version is correct. According to Equation (4) of the original article, mu should increase monotonically (e.g., mu4>=mu3), but if the original formula is followed, it may decrease in some cases. The formula of the original paper is 2h, but changing it to 2^h solves this problem. This function follow the latter interpretation.
Value
Ten Berge and Zegers' mu4 reliability estimate.
Author(s)
Eunseong Cho, bene@kw.ac.kr
References
Ten Berge, J. M. F., & Zegers, F. E. (1978). A series of lower bounds to the reliability of a test. Psychometrika, 43(4), 575-579.
Examples
mu4(Graham1)
Obtain multidimensional parallel reliability
Description
Multidimensional parallel reliability is derived from the multidimensional parallel model (Cho, 2016). This is equivalent to entering the correlation instead of the covariance into the stratified alpha formula.
Usage
multi_parallel(x, until)
Arguments
x |
observed item scores or their covariances |
until |
The number of items up to the first sub-construct |
Value
a multidimensional parallel reliability estimate
References
Cho, E. (2016). Making reliability reliable: A systematic approach to reliability coefficients. Organizational Research Methods, 19(4), 651–682.
Compare multiple multidimensional reliability estimates
Description
This function calculates various multidimensional reliability coefficients including maximal reliability, correlated factors, stratified alpha, second-order factor, bifactor, and Nunnally's bottom-up approach.
Usage
multirel(x, until, standardized = FALSE, ...)
Arguments
x |
a data frame of raw data or a covariance matrix |
until |
a vector of indices indicating the last item of each sub-dimension |
standardized |
If TRUE, the calculation is based on the correlation matrix. |
... |
Additional arguments passed to the underlying estimation functions. |
Value
a list of class 'reliacoef' containing multiple multidimensional estimates
Author(s)
Eunseong Cho, bene@kw.ac.kr
Examples
multirel(Cho_multi, c(3, 6, 9))
Obtain bottom-up approach multidimensional reliability estimates
Description
Among several approaches to estimating multidimensional reliability, these estimators use a bottom-up approach. That is, the test score is divided into sub-dimensional or sub-test scores. Multidimensional reliability is obtained by estimating the reliability of each subtest score and combining them. Different estimates can be obtained depending on how each subtest reliability is estimated. These estimators use the general formula first proposed by Jum Nunnally.
Usage
nunnally(x, until, method = "joreskog", standardized = FALSE)
Arguments
x |
a data frame of raw data or a covariance matrix |
until |
a vector of indices indicating the last item of each sub-dimension |
method |
There are three options: "joreskog" (default), "mu" (uses mu4), and "kaisercaffrey". |
standardized |
If TRUE, the calculation is based on the correlation matrix. |
Value
a list of class 'reliacoef' containing bottom-up multidimensional reliability estimates
Author(s)
Eunseong Cho, bene@kw.ac.kr
References
Nunnally, J. C., & Bernstein, I. H. (1994). Psychometric theory (3rd ed). McGraw-Hill.
Examples
nunnally(Cho_multi, c(3, 6, 9), method = "mu")
nunnally(Cho_multi, c(3, 6, 9), method = "kaisercaffrey")
Obtain second-order factor reliability estimates
Description
Obtain second-order factor reliability estimates. It is a multidimensional CFA reliability coefficient derived from the second-order factor model. Items should be grouped by each sub-dimension.
Usage
second_order(x, until, standardized = FALSE)
Arguments
x |
a data frame of raw data or a covariance matrix |
until |
a vector of indices indicating the last item of each sub-dimension |
standardized |
If TRUE, the calculation is based on the correlation matrix. |
Value
a list of class 'reliacoef' containing second-order factor reliability estimates
Author(s)
Eunseong Cho, bene@kw.ac.kr
References
Cho, E. (2016). Making reliability reliable: A systematic approach to reliability coefficients. Organizational Research Methods, 19(4), 651-682. https://doi.org/10.1177/1094428116656239
Examples
second_order(Cho_multi, c(3, 6, 9))
Obtain Simsek-Noyan's theta (multidimensional PCA reliability)
Description
Simsek-Noyan's (2013) theta is the multidimensional principal component analysis (PCA) reliability. It is a multidimensional generalization of Kaiser-Caffrey's alpha.
Usage
simsek(x, dim, standardized = FALSE)
Arguments
x |
a data frame of raw data or a covariance matrix |
dim |
the number of dimensions |
standardized |
If TRUE, the calculation is based on the correlation matrix. |
Value
Simsek-Noyan's theta
Author(s)
Eunseong Cho, bene@kw.ac.kr
References
Armor, D. J. (1974). Theta reliability and factor scaling. In H. L. Costner (Ed.), Sociological methodology (pp. 17-50). Jossey-Bass.
Kaiser, H. F., & Caffrey, J. (1965). Alpha factor analysis. Psychometrika, 30(1), 1-14.
Simsek, G. G., & Noyan, F. (2013). McDonald's omega_t, Cronbach's alpha, and Generalized theta for Composite Reliability of Common Factors Structures. Communications in Statistics - Simulation and Computation, 42(9), 2008-2025. https://doi.org/10.1080/03610918.2012.689062
Examples
simsek(Cho_multi, dim = 4)
Obtain standardized alpha
Description
Obtain standardized alpha
Usage
std_alpha(x)
Arguments
x |
a data frame of raw data or a covariance matrix |
Value
standardized alpha reliability estimate
Examples
std_alpha(Graham1)
Obtain stratified alpha reliability estimates
Description
Obtain stratified alpha reliability estimates. It is a multidimensional version of coefficient alpha. Items should be grouped by each sub-dimension.
Usage
stratified_alpha(x, until, standardized = FALSE)
Arguments
x |
a data frame of raw data or a covariance matrix |
until |
a vector of indices indicating the last item of each sub-dimension |
standardized |
If TRUE, the calculation is based on the correlation matrix. |
Value
a list of class 'reliacoef' containing stratified alpha reliability estimates
Author(s)
Eunseong Cho, bene@kw.ac.kr
References
Rajaratnam, N., Cronbach, L. J., & Gleser, G. C. (1965). Generalizability of stratified-parallel tests. Psychometrika, 30(1), 39–56. https://doi.org/10.1007/BF02289746
Cho, E. (2016). Making reliability reliable: A systematic approach to reliability coefficients. Organizational Research Methods, 19(4), 651-682. https://doi.org/10.1177/1094428116656239
Examples
stratified_alpha(Cho_multi, c(3, 6, 9))
Test the essential tau-equivalence of the data
Description
Compares goodness-of-fit indices between the essential tau-equivalence model and the congeneric model. It is used to test the assumption required for coefficient alpha and to investigate unidimensionality.
Usage
test.tauequivalence(data, standardized = FALSE)
Arguments
data |
a dataframe or a matrix (unidimensional) |
standardized |
If TRUE, the calculation is based on the correlation matrix. |
Value
a list of class 'reliacoef' containing fit indices and chi-square difference test
Author(s)
Eunseong Cho, bene@kw.ac.kr
References
Graham, J. M. (2006). Congeneric and (essentially) tau-equivalent estimates of score reliability what they are and how to use them. Educational and Psychological Measurement, 66(6), 930-944.
Examples
test.tauequivalence(Graham1)
Unidimensional confirmatory factor analysis
Description
Unidimensional confirmatory factor analysis
Usage
uni_cfa(
sigma,
what = "est",
sample_size = 500,
nonneg_error = TRUE,
taueq = FALSE,
parallel = FALSE
)
Arguments
sigma |
a covariance matrix |
what |
e.g., "est", "std", "fit" |
sample_size |
number of sample observations |
nonneg_error |
if TRUE, constraint error variances to positive values |
taueq |
if TRUE, a tau-equivalent model is estimated |
parallel |
if TRUE, a parallel model is estimated |
Value
parameter estimates of unidimensional cfa model
Examples
uni_cfa(Graham1)
Obtain Various Unidimensional Reliability Coefficients
Description
This function calculates multiple reliability coefficients simultaneously.
Usage
unirel(x, standardized = FALSE, psych.include = TRUE)
Arguments
x |
a data frame of raw data or a covariance matrix |
standardized |
If TRUE, calculations are based on the correlation matrix. |
psych.include |
Whether to include reliability coefficients (GLB.algebraic, GLB.fa) provided by the package psych. |
Value
A list of class 'reliacoef' containing reliability estimates.
Author(s)
Eunseong Cho, bene@kw.ac.kr
References
Cho, E. (2021). Neither Cronbach's alpha nor McDonald's omega: A comment on Sijtsma and Pfadt. Psychometrika, 86(4), 877-886.
Guttman, L. (1945). A basis for analyzing test-retest reliability. Psychometrika, 10(4), 255-282.
See Also
[alpha()] for coefficient alpha.
Examples
unirel(Graham1)